@@ -23,11 +23,10 @@
 #include "kz-smart-bookmark-action.h"
 
 #include <gdk/gdkkeysyms.h>
-
-#include "gtk24backports.h"
+#include <glib/gi18n.h>
 
 #include "kazehakase.h"
-#include "intl.h"
+#include "kz-smart-bookmark.h"
 #include "utils/utils.h"
 #include "utils/gtk-utils.h"
 #include "gobject-utils.h"
@@ -211,6 +210,20 @@ kz_smart_bookmark_action_set_property (GObject         *object,
 		break;
 	case PROP_KZ_BOOKMARK:
 		action->bookmark = g_object_ref(g_value_get_object(value));
+		/* if bookmark is a folder, connect signals */
+		if (kz_bookmark_is_folder(action->bookmark))
+		{
+			cb_bookmark_updated(action->bookmark, action);
+	/*		g_signal_connect(G_OBJECT(bookmark), "children-reordered",
+					 G_CALLBACK(cb_bookmark_updated),
+					 action);*/
+			g_signal_connect_after(G_OBJECT(action->bookmark), "insert-child",
+					 G_CALLBACK(cb_bookmark_insert_child),
+					 action);
+			g_signal_connect(G_OBJECT(action->bookmark), "remove-child",
+					 G_CALLBACK(cb_bookmark_remove_child),
+					 action);	
+		}
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -270,6 +283,7 @@ kz_smart_bookmark_action_activate (GtkAction *action)
 		kz_window_open_new_tab(smart_action->kz, smart_uri);
 	else	
 		kz_window_load_url(smart_action->kz, smart_uri);
+	
 	g_free(smart_uri);
 }
 
@@ -362,31 +376,16 @@ kz_smart_bookmark_action_new (KzWindow *kz, KzBookmark *bookmark)
 	else
 		name = g_strdup_printf("SmartBookmark:%p", bookmark);
 
-	action = KZ_SMART_BOOKMARK_ACTION(
-			g_object_new(KZ_TYPE_SMART_BOOKMARK_ACTION,
-				     "name",        name,
-				     "label",       _("Entry"),
-				     "tooltip",     NULL,
-				     "stock_id",    KZ_STOCK_SEARCH,
-				     "kz-window",   kz,
-				     "kz-bookmark", bookmark,
-				     NULL));
+	action = g_object_new(KZ_TYPE_SMART_BOOKMARK_ACTION,
+			      "name",        name,
+			      "label",       _("Entry"),
+			      "tooltip",     NULL,
+			      "stock_id",    KZ_STOCK_SEARCH,
+			      "kz-window",   kz,
+			      "kz-bookmark", bookmark,
+			      NULL);
 	g_free(name);
-	
-	/* if bookmark is a folder, connect signals */
-	if (kz_bookmark_is_folder(bookmark))
-	{
-		cb_bookmark_updated(bookmark, action);
-/*		g_signal_connect(G_OBJECT(bookmark), "children-reordered",
-				 G_CALLBACK(cb_bookmark_updated),
-				 action);*/
-		g_signal_connect_after(G_OBJECT(bookmark), "insert-child",
-				 G_CALLBACK(cb_bookmark_insert_child),
-				 action);
-		g_signal_connect(G_OBJECT(bookmark), "remove-child",
-				 G_CALLBACK(cb_bookmark_remove_child),
-				 action);	
-	}
+
 	return action;
 }
 
@@ -416,7 +415,7 @@ cb_entry_key_press (GtkWidget *widget, GdkEventKey *event,
 	{
 		gboolean newtab;
 		gchar *smart_uri;
-		
+
 		if (kz_bookmark_is_folder(action->bookmark) &&
 		    kz_bookmark_is_folder(action->menulist->data))
 		{
@@ -432,6 +431,7 @@ cb_entry_key_press (GtkWidget *widget, GdkEventKey *event,
 			kz_window_load_url(action->kz, smart_uri);
 		else 
 			kz_window_open_new_tab(action->kz, smart_uri);
+		
 		g_free(smart_uri);
 
 		return TRUE;
@@ -591,7 +591,7 @@ cb_bookmark_updated (KzBookmark *folder, KzSmartBookmarkAction *action)
 	{
 		KzBookmark *child= node->data;
 
-		if (!kz_bookmark_is_smart(child)) continue;
+		if (!KZ_IS_SMART_BOOKMARK(child)) continue;
 
 		menuitem = create_menu_item(action, child);
 		if (menuitem)
@@ -646,7 +646,7 @@ cb_bookmark_insert_child (KzBookmark *folder,
 {
 	GtkWidget *menuitem;
 
-	if (!kz_bookmark_is_smart(child)) return;
+	if (!KZ_IS_SMART_BOOKMARK(child)) return;
 	
 	menuitem = create_menu_item(action, child);
 	if (!menuitem) return;
@@ -717,7 +717,7 @@ cb_menuitem_activate (GtkWidget *menuitem, KzSmartBookmarkAction *action)
 
 
 
-void
+static void
 menu_position_under_widget (GtkMenu *menu, gint *x, gint *y,
 			    gboolean *push_in, gpointer user_data)
 {
@@ -776,7 +776,7 @@ get_smart_uri (KzSmartBookmarkAction *action)
 		bookmark = action->bookmark;
 	
 	uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
-	smart_uri = kz_bookmark_get_smart_uri(bookmark, uri);
+	smart_uri = kz_smart_bookmark_get_smart_uri(KZ_SMART_BOOKMARK(bookmark), uri);
 
 	return smart_uri;
 }
@@ -802,9 +802,9 @@ get_smart_uris (KzSmartBookmarkAction *action)
 	uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
 	for (node = children; node; node = g_list_next(node))
 	{
-		KzBookmark *bookmark = node->data;
+		KzSmartBookmark *bookmark = node->data;
 		
-		smart_uris[i] = kz_bookmark_get_smart_uri(bookmark, uri);
+		smart_uris[i] = kz_smart_bookmark_get_smart_uri(bookmark, uri);
 		i++;
 	}
 	g_list_free(children);
