@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-file.c,v 1.8 2004/11/24 11:35:56 ikezoe Exp $
+ *  $Id: kz-bookmark-file.c,v 1.10 2004/12/11 14:17:53 tyuyu Exp $
  */
 
 #include "kz-bookmark-file.h"
@@ -41,6 +41,7 @@
 #include "kz-nsbookmark.h"
 #include "kz-lirs.h"
 #include "kz-hinadi.h"
+#include "kz-w3mbookmark.h"
 
 enum {
 	LOAD_START_SIGNAL,
@@ -134,6 +135,7 @@ kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
 		ADD_BOOKMARK_FILE_TYPE(kz_hinadi_get_file_types);
 		ADD_BOOKMARK_FILE_TYPE(kz_xbel_get_file_types);
 		ADD_BOOKMARK_FILE_TYPE(kz_nsbookmark_get_file_types);
+		ADD_BOOKMARK_FILE_TYPE(kz_w3mbookmark_get_file_types);
 	}
 
 	parent_class = g_type_class_peek_parent (klass);
