@@ -17,13 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.c,v 1.10 2004/10/14 17:49:20 ikezoe Exp $
+ *  $Id: kz-root-bookmark.c,v 1.12 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-root-bookmark.h"
 
 #include <glib/gi18n.h>
 #include "gobject-utils.h"
+#include "kz-bookmark-file.h"
 
 
 static void     kz_root_bookmark_class_init  (KzRootBookmarkClass *klass);
@@ -58,12 +59,12 @@ kz_root_bookmark_class_init (KzRootBookmarkClass *klass)
 static void
 kz_root_bookmark_init (KzRootBookmark *root)
 {
-	root->menu            = kz_bookmark_file_new(NULL, NULL, NULL);
-	root->clip            = kz_bookmark_file_new(NULL, NULL, NULL);
+	root->menu            = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
+	root->clip            = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
 	root->bookmark_bars   = kz_bookmark_pure_folder_new();
 	root->history         = kz_history_new(NULL);
 	root->sessions        = kz_bookmark_pure_folder_new();
-	root->current_session = kz_bookmark_file_new(NULL, NULL, NULL);
+	root->current_session = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
 	root->tab_groups      = kz_bookmark_pure_folder_new();
 	root->smarts          = NULL;
 
@@ -154,10 +155,10 @@ kz_root_bookmark_new (const gchar *menu_file,  const gchar *sys_menu_file,
 {
 	KzRootBookmark *root;
 
-	root = KZ_ROOT_BOOKMARK(g_object_new(KZ_TYPE_ROOT_BOOKMARK,
-					     "type",  KZ_BOOKMARK_PURE_FOLDER,
-					     "title", _("Root"),
-					     NULL));
+	root = g_object_new(KZ_TYPE_ROOT_BOOKMARK,
+			    "type",  KZ_BOOKMARK_PURE_FOLDER,
+			    "title", _("Root"),
+			    NULL);
 
 	if (root->menu)
 		kz_bookmark_append(KZ_BOOKMARK(root), root->menu);
@@ -183,7 +184,7 @@ static KzBookmark *
 ensure_bookmark_file (const gchar *file, const gchar *subfile,
 		      const gchar *title, const gchar *type)
 {
-	KzBookmark *bookmark;
+	KzBookmarkFile *bookmark;
 
 	g_return_val_if_fail(file && *file, NULL);
 	g_return_val_if_fail(type && *type, NULL);
@@ -191,22 +192,22 @@ ensure_bookmark_file (const gchar *file, const gchar *subfile,
 	if (g_file_test(file, G_FILE_TEST_EXISTS))
 	{
 		bookmark = kz_bookmark_file_new(file, title, type);
-		kz_bookmark_load_start(bookmark);
+		kz_bookmark_file_load_start(bookmark);
 	}
 	else if (subfile && *subfile &&
 		 g_file_test(subfile, G_FILE_TEST_EXISTS))
 	{
 		bookmark = kz_bookmark_file_new(subfile, title, type);
-		kz_bookmark_load_start(bookmark);
+		kz_bookmark_file_load_start(bookmark);
 	}
 	else
 	{
 		bookmark = kz_bookmark_file_create_new(file, title, type);
 	}
 
-	kz_bookmark_set_location(bookmark, file);
+	kz_bookmark_file_set_location(bookmark, file);
 
-	return bookmark;
+	return KZ_BOOKMARK(bookmark);
 }
 
 
@@ -302,7 +303,7 @@ void
 kz_root_bookmark_add_bookmark_bar_file (KzRootBookmark *root,
 					const gchar *file, const gchar *subfile)
 {
-	KzBookmark *bar;
+	KzBookmarkFile *bar;
 
 	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
 	g_return_if_fail(file && *file);
@@ -330,10 +331,10 @@ kz_root_bookmark_add_bookmark_bar_file (KzRootBookmark *root,
 						  "XBEL");
 	}
 
-	kz_bookmark_load_start(bar);
-	kz_bookmark_set_location(bar, file);
+	kz_bookmark_file_load_start(bar);
+	kz_bookmark_file_set_location(bar, file);
 
-	kz_bookmark_append(root->bookmark_bars, bar);
+	kz_bookmark_append(root->bookmark_bars, KZ_BOOKMARK(bar));
 	g_object_unref(bar);
 }
 
@@ -342,7 +343,7 @@ void
 kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 					   const gchar *file)
 {
-	KzBookmark *current_session;
+	KzBookmarkFile *current_session;
 
 	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
 	g_return_if_fail(file && *file);
@@ -371,8 +372,8 @@ kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 
 	if (current_session)
 	{
-		kz_bookmark_load(current_session);
-		root->current_session = current_session;
+		kz_bookmark_file_load(current_session);
+		root->current_session = KZ_BOOKMARK(current_session);
 		/*	
 		kz_bookmark_insert_before(KZ_BOOKMARK(root),
 					  current_session, root->bookmark_bars);
@@ -390,9 +391,9 @@ kz_root_bookmark_save_all (KzRootBookmark *root)
 	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
 
 	if (root->menu)
-		kz_bookmark_save(root->menu);
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(root->menu));
 	if (root->clip)
-		kz_bookmark_save(root->clip);
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(root->clip));
 
 	if (root->bookmark_bars)
 	{
@@ -403,12 +404,12 @@ kz_root_bookmark_save_all (KzRootBookmark *root)
 		{
 			KzBookmark *bar = node->data;
 
-			if (!KZ_IS_BOOKMARK(bar) || !kz_bookmark_is_file(bar))
+			if (!KZ_IS_BOOKMARK(bar) || !KZ_IS_BOOKMARK_FILE(bar))
 				g_warning("Invalid bookmark bar file!");
-			kz_bookmark_save(bar);
+			kz_bookmark_file_save(KZ_BOOKMARK_FILE(bar));
 		}
 		g_list_free(children);
 	}
 	if (root->smarts)
-		kz_bookmark_save(root->smarts);
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(root->smarts));
 }
