@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.58 2004/10/31 06:38:18 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.59 2004/12/05 08:06:06 tyuyu Exp $
  */
 
 #include "kazehakase.h"
@@ -363,6 +363,12 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_lock(bookmark, TRUE);
 			}
+			else if (!strncmp(attr->name, "kz:auto_refresh", 15))
+			{
+				if (!strcmp(attr->value, "yes"))
+					kz_bookmark_set_auto_refresh(bookmark, TRUE);
+			}
+
 		}
 
 		if (smart_regex && smart_uri)
@@ -914,6 +920,7 @@ create_xml_node (KzBookmark *bookmark)
 		KzXMLNode *metanode;
 		gint pos = kz_bookmark_get_current(bookmark);
 		gboolean lock = kz_bookmark_get_lock(bookmark);
+		gboolean auto_refresh = kz_bookmark_get_auto_refresh(bookmark);
 		/*
 		 * <folder>\n
 		 * <title/>
@@ -928,7 +935,7 @@ create_xml_node (KzBookmark *bookmark)
 
 		xml_node_append_title (node, bookmark);
 		
-		if (pos || lock)
+		if (pos || lock || auto_refresh)
 		{
 			metanode = xml_node_find_metadata_node(node);
 	
@@ -949,6 +956,16 @@ create_xml_node (KzBookmark *bookmark)
 					str = "no";
 				kz_xml_node_set_attr(metanode, "kz:lock", str);
 			}
+			if (auto_refresh)
+			{
+				const gchar *str;
+				if (auto_refresh)
+					str = "yes";
+				else
+					str = "no";
+				kz_xml_node_set_attr(metanode, "kz:auto_refresh", str);
+			}
+
 		}
 	}
 	else if (KZ_IS_SMART_BOOKMARK(bookmark))
@@ -1334,6 +1351,24 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 
 		kz_xml_node_set_attr(metanode, "kz:lock", str);
 	}
+	else if (!strcmp(prop, "auto-refresh"))
+	{
+		KzXMLNode *metanode;
+		const gchar *str;
+		gboolean auto_refresh = g_value_get_boolean(&value);
+		
+		if (auto_refresh)
+			str = "yes";
+		else
+			str = "no";
+
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:auto_refresh", str);
+	}
 	g_value_unset(&value);
 }
 
