@@ -53,16 +53,15 @@ typedef enum {
 KzUILevel    kz_ui_level           (void);
 KzUILevel    kz_ui_level_from_str  (const gchar *level);
 const gchar *kz_ui_level_to_str    (KzUILevel level);
-const gchar *kz_ui_level_to_suffix (KzUILevel level);
 
 
 extern KzProfile      *kz_global_profile;
-extern KzProfile      *kz_session;
 extern KzProfile      *kz_proxy;
 extern KzRootBookmark *kz_bookmarks;
 #if USE_MIGEMO
 extern Migemo         *migemo;
 #endif
+extern gboolean	       is_restoring_session;
 
 extern gboolean        exists_estindex; 
 extern gchar          *estversion;
