@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-icons.h,v 1.23 2004/09/15 10:06:36 ikezoe Exp $
+ *  $Id: kz-icons.h,v 1.24 2004/12/12 10:31:02 ikezoe Exp $
  */
 
 #ifndef KZ_ICONS_H
@@ -61,6 +61,13 @@ G_BEGIN_DECLS
 #define KZ_STOCK_TAB_PREV           "kz-tab-prev"
 #define KZ_STOCK_VIEW_SOURCE        "kz-view-source"
 
+#define KZ_STOCK_MOZILLA	    "kz-mozilla"
+#define KZ_STOCK_FIREFOX	    "kz-firefox"
+#define KZ_STOCK_EPIPHANY	    "kz-epiphany"
+#define KZ_STOCK_GALEON		    "kz-galeon"
+#define KZ_STOCK_NETSCAPE	    "kz-netscape"
+#define KZ_STOCK_KONQUEROR 	    "kz-konqueror"
+
 extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;
 
 extern GdkPixbuf *kz_icon;
