@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.4 2004/09/14 14:06:41 ikezoe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.5 2004/09/30 00:06:07 ikezoe Exp $
  */
 
 /*
@@ -54,9 +54,9 @@
 
 #include <gtk/gtk.h>
 #include <time.h>
+#include <glib/gi18n.h>
 
 #include "GtkNSSDialogs.h"
-#include "intl.h"
 #include "glib-utils.h"
 
 NS_DEFINE_CID (kX509CertCID, NS_IX509CERT_IID);
